==> digikam-4.5.0.tar.bz2: digikam-4.5.0/extra/kipi-plugins/mediawiki/kipiplugin_wikimedia.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=MediaWiki Export
Name=MediaWiki Export
Name[bs]=MediaWiki Izvoz
Name[ca]=Exportador a MediaWiki
Name[ca@valencia]=Exportador a MediaWiki
Name[cs]=Export MediaWiki
Name[da]=MediaWiki-eksport
Name[de]=MediaWiki-Export
Name[el]=Εξαγωγή στο MediaWiki
Name[en_GB]=MediaWiki Export
Name[es]=Exportar a MediaWiki
Name[et]=MediaWiki eksport
Name[fi]=MediaWiki-vienti
Name[fr]=Exportation « MediaWiki »
Name[ga]=Easpórtáil MediaWiki
Name[gl]=Exportación a MediaWiki
Name[hu]=MediaWiki exportálás
Name[is]=MediaWiki útflutningur
Name[it]=Esportazione a MediaWiki
Name[nb]=MediaWiki-eksport
Name[nl]=Naar MediaWiki exporteren
Name[pl]=Eksport do MediaWiki
Name[pt]=Exportação para o MediaWiki
Name[pt_BR]=Exportar para o MediaWiki
Name[sk]=MediaWiki Export
Name[sl]=Izvoz MediaWiki
Name[sv]=Export till Wikimedia
Name[tr]=MediaWiki Aktarımı
Name[uk]=Експорт до MediaWiki
Name[x-test]=xxMediaWiki Exportxx
Name[zh_TW]=MediaWiki 匯出
Comment=A tool to export images to a remote MediaWiki web service
Comment[bs]=Alat za izvoz slike kontrolnom  MediaWiki web servisu
Comment[ca]=Una eina per exportar imatges a un servei web remot de MediaWiki
Comment[ca@valencia]=Una eina per exportar imatges a un servei web remot de MediaWiki
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby MediaWiki
Comment[da]=Et værktøj til at eksportere billeder til en ekstern MediaWiki-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten MediaWiki-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού MediaWiki
Comment[en_GB]=A tool to export images to a remote MediaWiki web service
Comment[es]=Una herramienta para exportar imágenes al servicio web de MediaWiki
Comment[et]=Tööriist piltide eksportimiseks MediaWiki veebiteenusesse
Comment[fr]=Outil d'exportation d'images vers le service en ligne « MediaWiki »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin MediaWiki i gcéin
Comment[gl]=Ferramenta para exportar imaxes a un servizo web MediaWiki remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli MediaWiki webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga MediaWiki vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto MediaWiki
Comment[nb]=Et verktøy for å eksportere bilder til en MediaWiki-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een MediaWiki-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej MediaWiki
Comment[pt]=Uma ferramenta de exportação de imagens para um serviço Web remoto do MediaWiki
Comment[pt_BR]=Uma ferramenta para exportar imagens para o serviço remoto da Internet MediaWiki
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu MediaWiki
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev MediaWiki
Comment[sv]=Ett verktyg för att exportera bilder till en Mediawiki webbtjänst
Comment[tr]=Resimleri uzak bir MediaWiki web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби MediaWiki
Comment[x-test]=xxA tool to export images to a remote MediaWiki web servicexx
Comment[zh_TW]=匯出影像到遠端 MediaWiki 網頁服務的工具
Icon=kipi-wikimedia
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_wikimedia
author=Guillaume Hormiere, hormiere dot guillaume at gmail dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/mediawiki/kipiplugin_wikimedia.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=MediaWiki Export
Name=MediaWiki Export
Name[bs]=MediaWiki Izvoz
Name[ca]=Exportador a MediaWiki
Name[ca@valencia]=Exportador a MediaWiki
Name[cs]=Export MediaWiki
Name[da]=MediaWiki-eksport
Name[de]=MediaWiki-Export
Name[el]=Εξαγωγή στο MediaWiki
Name[en_GB]=MediaWiki Export
Name[es]=Exportar a MediaWiki
Name[et]=MediaWiki eksport
Name[fi]=MediaWiki-vienti
Name[fr]=Exportation « MediaWiki »
Name[ga]=Easpórtáil MediaWiki
Name[gl]=Exportación a MediaWiki
Name[hu]=MediaWiki exportálás
Name[is]=MediaWiki útflutningur
Name[it]=Esportazione a MediaWiki
Name[nb]=MediaWiki-eksport
Name[nl]=Naar MediaWiki exporteren
Name[pl]=Eksport do MediaWiki
Name[pt]=Exportação para o MediaWiki
Name[pt_BR]=Exportar para o MediaWiki
Name[sk]=MediaWiki Export
Name[sl]=Izvoz MediaWiki
Name[sv]=Export till Wikimedia
Name[tr]=MediaWiki Aktarımı
Name[uk]=Експорт до MediaWiki
Name[x-test]=xxMediaWiki Exportxx
Name[zh_TW]=MediaWiki 匯出
Comment=A tool to export images to a remote MediaWiki web service
Comment[bs]=Alat za izvoz slike kontrolnom  MediaWiki web servisu
Comment[ca]=Una eina per exportar imatges a un servei web remot de MediaWiki
Comment[ca@valencia]=Una eina per exportar imatges a un servei web remot de MediaWiki
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby MediaWiki
Comment[da]=Et værktøj til at eksportere billeder til en ekstern MediaWiki-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten MediaWiki-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού MediaWiki
Comment[en_GB]=A tool to export images to a remote MediaWiki web service
Comment[es]=Una herramienta para exportar imágenes al servicio web de MediaWiki
Comment[et]=Tööriist piltide eksportimiseks MediaWiki veebiteenusesse
Comment[fi]=Kuvien vienti MediaWiki-verkkopalveluun
Comment[fr]=Outil d'exportation d'images vers le service en ligne « MediaWiki »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin MediaWiki i gcéin
Comment[gl]=Ferramenta para exportar imaxes a un servizo web MediaWiki remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli MediaWiki webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga MediaWiki vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto MediaWiki
Comment[nb]=Et verktøy for å eksportere bilder til en MediaWiki-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een MediaWiki-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej MediaWiki
Comment[pt]=Uma ferramenta de exportação de imagens para um serviço Web remoto do MediaWiki
Comment[pt_BR]=Ferramenta para exportar imagens para o MediaWiki
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu MediaWiki
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev MediaWiki
Comment[sv]=Ett verktyg för att exportera bilder till en Mediawiki webbtjänst
Comment[tr]=Resimleri uzak bir MediaWiki web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби MediaWiki
Comment[x-test]=xxA tool to export images to a remote MediaWiki web servicexx
Comment[zh_TW]=匯出影像到遠端 MediaWiki 網頁服務的工具
Icon=kipi-wikimedia
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_wikimedia
author=Guillaume Hormiere, hormiere dot guillaume at gmail dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
